summaryrefslogtreecommitdiffstats
path: root/net/disk_cache
diff options
context:
space:
mode:
authorvadimt <vadimt@chromium.org>2014-10-29 15:10:41 -0700
committerCommit bot <commit-bot@chromium.org>2014-10-29 22:11:04 +0000
commit09e7ebe02c71d923e4655a0ad5e151b97344f091 (patch)
tree116297765f286720af9aff161fafeca63486a1a6 /net/disk_cache
parent2ab60d98289be5804e38ea8fdebcf78740fca095 (diff)
downloadchromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.zip
chromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.tar.gz
chromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.tar.bz2
Switching profiler instrumentations from ScopedProfile to ScopedTracker. This will disable the instrumentations in all channels except Canary, and developer build. Instrumentations are only enabled in Browser process.
This will prevent Stable from sending increased amounts of UMA logs. Also, this will let us observe "true" (untouched by instrumentations) jankiness numbers every week in Dev channel. BUG=401560 Review URL: https://codereview.chromium.org/686963002 Cr-Commit-Position: refs/heads/master@{#301950}
Diffstat (limited to 'net/disk_cache')
-rw-r--r--net/disk_cache/blockfile/in_flight_backend_io.cc10
-rw-r--r--net/disk_cache/blockfile/in_flight_io.cc6
-rw-r--r--net/disk_cache/cache_creator.cc6
3 files changed, 11 insertions, 11 deletions
diff --git a/net/disk_cache/blockfile/in_flight_backend_io.cc b/net/disk_cache/blockfile/in_flight_backend_io.cc
index 9bb011e..2cb3ff0 100644
--- a/net/disk_cache/blockfile/in_flight_backend_io.cc
+++ b/net/disk_cache/blockfile/in_flight_backend_io.cc
@@ -8,7 +8,7 @@
#include "base/bind_helpers.h"
#include "base/compiler_specific.h"
#include "base/logging.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/single_thread_task_runner.h"
#include "net/base/net_errors.h"
#include "net/disk_cache/blockfile/backend_impl.h"
@@ -66,9 +66,9 @@ void BackendIO::OnDone(bool cancel) {
if (result() == net::OK) {
static_cast<EntryImpl*>(*entry_ptr_)->OnEntryCreated(backend_);
if (cancel) {
// TODO(vadimt): Remove ScopedProfile below once crbug.com/422516 is
// fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION("422516 BackendIO::OnDone"));
(*entry_ptr_)->Close();
@@ -504,8 +504,8 @@ void InFlightBackendIO::OnOperationComplete(BackgroundIO* operation,
op->OnDone(cancel);
if (!op->callback().is_null() && (!cancel || op->IsEntryOperation())) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422516 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422516 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422516 InFlightBackendIO::OnOperationComplete"));
@@ -66,9 +66,9 @@ void BackendIO::OnDone(bool cancel) {
static_cast<EntryImpl*>(*entry_ptr_)->OnEntryCreated(backend_);
if (cancel) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422516 is
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422516 is
// fixed.
diff --git a/net/disk_cache/blockfile/in_flight_io.cc b/net/disk_cache/blockfile/in_flight_io.cc
index 176cf87..cbfcd17 100644
--- a/net/disk_cache/blockfile/in_flight_io.cc
+++ b/net/disk_cache/blockfile/in_flight_io.cc
@@ -7,7 +7,7 @@
#include "base/bind.h"
#include "base/location.h"
#include "base/logging.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/single_thread_task_runner.h"
#include "base/task_runner.h"
#include "base/thread_task_runner_handle.h"
@@ -88,8 +88,8 @@ void InFlightIO::OnIOComplete(BackgroundIO* operation) {
// Runs on the primary thread.
void InFlightIO::InvokeCallback(BackgroundIO* operation, bool cancel_task) {
{
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422516 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422516 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION("422516 InFlightIO::InvokeCallback"));
// http://crbug.com/74623
diff --git a/net/disk_cache/cache_creator.cc b/net/disk_cache/cache_creator.cc
index becb31c..93c06b3 100644
--- a/net/disk_cache/cache_creator.cc
+++ b/net/disk_cache/cache_creator.cc
@@ -4,7 +4,7 @@
#include "base/files/file_path.h"
#include "base/metrics/field_trial.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/single_thread_task_runner.h"
#include "base/strings/stringprintf.h"
#include "net/base/cache_type.h"
@@ -140,8 +140,8 @@ void CacheCreator::DoCallback(int result) {
// If the initialization of the cache fails, and |force| is true, we will
// discard the whole cache and create a new one.
void CacheCreator::OnIOComplete(int result) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422516 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422516 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION("422516 CacheCreator::OnIOComplete"));
if (result == net::OK || !force_ || retry_)